{{SUMMARY}}

The main functionality of Basix is written in C++. Documentation of the C++ functionality of Basix can be found
at {{link:URL/cpp}}.

The majority of the functionality of Basix is available for use through the Python interface. Documentation of
this interface can be found at {{link:URL/python}}.

## Installing Basix
Instructions for installing Basix can be found at {{link:URL/install.html}}.

## Source
The source code of Basix is available [on GitHub](https://github.com/FEniCS/basix). It is available under
an [MIT license](https://github.com/FEniCS/basix/blob/main/LICENSE).

{{SUPPORTED ELEMENTS}}
